==> haskell-text-builder-dev-0.3.3.2-236.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder-dev.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-builder-dev
version:              0.3.3.2
visibility:           public
id:                   text-builder-dev-0.3.3.2-KtXsOcYvoZwLb682mlM259
key:                  text-builder-dev-0.3.3.2-KtXsOcYvoZwLb682mlM259
license:              MIT
copyright:            (c) 2022, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder-dev
synopsis:             Edge of developments for "text-builder"
description:
    This is a development version of \"text-builder\".
    All experimentation and feature development happens here.
    The API can change drastically.
    For a more stable API use \"text-builder\",
    which is now just a wrapper over this package.

category:             Text
abi:                  4bbdc57303b8640b60da067e1dce4ac4
exposed:              True
exposed-modules:      TextBuilderDev
hidden-modules:
    TextBuilderDev.Allocator TextBuilderDev.Unicode
    TextBuilderDev.Utf16View TextBuilderDev.Utf8View
    TextBuilderDev.Prelude

import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-builder-dev-0.3.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-builder-dev-0.3.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-builder-dev-0.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder-dev
hs-libraries:         HStext-builder-dev-0.3.3.2-KtXsOcYvoZwLb682mlM259
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    deferred-folds-0.9.18.7-3YASkbivcMDDaPil1p3K3o
    isomorphism-class-0.1.1-1OnDLySkELaBMMH5G6Xhen
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 text-2.0.2 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-text-builder-dev/html/text-builder-dev.haddock

haddock-html:         /usr/share/doc/haskell-text-builder-dev/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-builder-dev-0.3.3.2-237-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-text-builder-dev.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-builder-dev
version:              0.3.3.2
visibility:           public
id:                   text-builder-dev-0.3.3.2-L58l8PPDN2E4ITBQArlBLY
key:                  text-builder-dev-0.3.3.2-L58l8PPDN2E4ITBQArlBLY
license:              MIT
copyright:            (c) 2022, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/text-builder-dev
synopsis:             Edge of developments for "text-builder"
description:
    This is a development version of \"text-builder\".
    All experimentation and feature development happens here.
    The API can change drastically.
    For a more stable API use \"text-builder\",
    which is now just a wrapper over this package.

category:             Text
abi:                  13ecf58ec9d79609c3aef0196bf31227
exposed:              True
exposed-modules:      TextBuilderDev
hidden-modules:
    TextBuilderDev.Allocator TextBuilderDev.Unicode
    TextBuilderDev.Utf16View TextBuilderDev.Utf8View
    TextBuilderDev.Prelude

import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-builder-dev-0.3.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-builder-dev-0.3.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-builder-dev-0.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-builder-dev
hs-libraries:         HStext-builder-dev-0.3.3.2-L58l8PPDN2E4ITBQArlBLY
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    deferred-folds-0.9.18.7-AQVjI6sElLgFSTBjW4DXpU
    isomorphism-class-0.1.1-JbG9Rrh2owUFvc258UYodK
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 text-2.0.2 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-text-builder-dev/html/text-builder-dev.haddock

haddock-html:         /usr/share/doc/haskell-text-builder-dev/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
